@@ -1,10 +1,10 @@
 package Alien::FLTK;
-{ $Alien::FLTK::VERSION = 'v1.3.2'; }
+{ $Alien::FLTK::VERSION = 'v1.3.4'; }
 use strict;
 use warnings;
 use File::ShareDir qw[dist_dir];
 use File::Spec::Functions qw[catdir canonpath];
-use JSON::PP 2 qw[decode_json];
+use JSON::Tiny qw[decode_json];
 use File::Slurp qw[read_file];
 use lib '../../blib/lib', '../blib/lib', 'blib/lib', 'lib';
 
@@ -260,7 +260,7 @@ CPAN ID: SANKO
 
 =head1 License and Legal
 
-Copyright (C) 2009-2012 by Sanko Robinson E<lt>sanko@cpan.orgE<gt>
+Copyright (C) 2009-2020 by Sanko Robinson E<lt>sanko@cpan.orgE<gt>
 
 This program is free software; you can redistribute it and/or modify it under
 the terms of The Artistic License 2.0. See the F<LICENSE> file included with
@@ -275,6 +275,4 @@ clarification, see http://creativecommons.org/licenses/by-sa/3.0/us/.
 L<Alien::FLTK|Alien::FLTK> is based in part on the work of the FLTK project.
 See http://www.fltk.org/.
 
-=for git $Id: FLTK.pm fce12aa 2012-07-22 08:24:39Z sanko@cpan.org $
-
 =cut
